/* IMPORTANT
 * This snapshot file is auto-generated, but designed for humans.
 * It should be checked into source control and tracked carefully.
 * Re-generate by setting TAP_SNAPSHOT=1 and running tests.
 * Make sure to inspect the output below.  Do not ignore changes!
 */
'use strict'
exports[`test/index.js TAP > log levels 1`] = `
Array [
  "notice",
  "error",
  "warn",
  "info",
  "verbose",
  "http",
  "silly",
  "pause",
  "resume",
]
`
